Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/lib/libc/arch/sparc/gen Rename a parameter to fix build prob...



details:   https://anonhg.NetBSD.org/src/rev/21be14950841
branches:  trunk
changeset: 517195:21be14950841
user:      tron <tron%NetBSD.org@localhost>
date:      Thu Nov 08 11:24:07 2001 +0000

description:
Rename a parameter to fix build problem with new toolchain.

diffstat:

 lib/libc/arch/sparc/gen/ldexp.c |  30 +++++++++++++++---------------
 1 files changed, 15 insertions(+), 15 deletions(-)

diffs (103 lines):

diff -r 721bf242f83e -r 21be14950841 lib/libc/arch/sparc/gen/ldexp.c
--- a/lib/libc/arch/sparc/gen/ldexp.c   Thu Nov 08 09:45:34 2001 +0000
+++ b/lib/libc/arch/sparc/gen/ldexp.c   Thu Nov 08 11:24:07 2001 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: ldexp.c,v 1.9 1999/08/30 18:28:26 mycroft Exp $        */
+/*     $NetBSD: ldexp.c,v 1.10 2001/11/08 11:24:07 tron Exp $  */
 
 /*-
  * Copyright (c) 1999 The NetBSD Foundation, Inc.
@@ -38,7 +38,7 @@
 
 #include <sys/cdefs.h>
 #if defined(LIBC_SCCS) && !defined(lint)
-__RCSID("$NetBSD: ldexp.c,v 1.9 1999/08/30 18:28:26 mycroft Exp $");
+__RCSID("$NetBSD: ldexp.c,v 1.10 2001/11/08 11:24:07 tron Exp $");
 #endif /* LIBC_SCCS and not lint */
 
 #include <sys/types.h>
@@ -47,12 +47,12 @@
 #include <math.h>
 
 /*
- * Multiply the given value by 2^exp.
+ * Multiply the given value by 2^exponent.
  */
 double
-ldexp(val, exp)
+ldexp(val, expo)
        double val;
-       int exp;
+       int expo;
 {
        register int oldexp, newexp;
        union {
@@ -74,17 +74,17 @@
                 * u.v is denormal.  We must adjust it so that the exponent
                 * arithmetic below will work.
                 */
-               if (exp <= DBL_EXP_BIAS) {
+               if (expo <= DBL_EXP_BIAS) {
                        /*
                         * Optimization: if the scaling can be done in a single
                         * multiply, or underflows, just do it now.
                         */
-                       if (exp <= -DBL_FRACBITS) {
+                       if (expo <= -DBL_FRACBITS) {
                                errno = ERANGE;
                                return (0.0);
                        }
                        mul.v = 0.0;
-                       mul.s.dbl_exp = exp + DBL_EXP_BIAS;
+                       mul.s.dbl_exp = expo + DBL_EXP_BIAS;
                        u.v *= mul.v;
                        if (u.v == 0.0) {
                                errno = ERANGE;
@@ -93,14 +93,14 @@
                        return (u.v);
                } else {
                        /*
                         * We know that exp is very large, and therefore the
                         * result cannot be denormal (though it may be Inf).
                         * Shift u.v by just enough to make it normal.
                         */
                        mul.v = 0.0;
                        mul.s.dbl_exp = DBL_FRACBITS + DBL_EXP_BIAS;
                        u.v *= mul.v;
-                       exp -= DBL_FRACBITS;
+                       expo -= DBL_FRACBITS;
                        oldexp = u.s.dbl_exp;
                }
        }
@@ -109,7 +109,7 @@
         * u.v is now normalized and oldexp has been adjusted if necessary.
         * Calculate the new exponent and check for underflow and overflow.
         */
-       newexp = oldexp + exp;
+       newexp = oldexp + expo;
 
        if (newexp <= 0) {
                /*
@@ -121,17 +121,17 @@
                        return (0.0);
                }
                /*
                 * Denormalize the result.  We do this with a multiply.  If exp
                 * is very large, it won't fit in a double, so we have to
                 * adjust the exponent first.  This is safe because we know
                 * that u.v is normal at this point.
                 */
-               if (exp <= -DBL_EXP_BIAS) {
+               if (expo <= -DBL_EXP_BIAS) {
                        u.s.dbl_exp = 1;
-                       exp += oldexp - 1;
+                       expo += oldexp - 1;
                }
                mul.v = 0.0;
-               mul.s.dbl_exp = exp + DBL_EXP_BIAS;
+               mul.s.dbl_exp = expo + DBL_EXP_BIAS;
                u.v *= mul.v;
                return (u.v);
        } else if (newexp >= DBL_EXP_INFNAN) {
@@ -93,14 +93,14 @@
                } else {
                        /*
-                        * We know that exp is very large, and therefore the
+                        * We know that expo is very large, and therefore the
                         * result cannot be denormal (though it may be Inf).
                         * Shift u.v by just enough to make it normal.
@@ -121,17 +121,17 @@
                }
                /*
-                * Denormalize the result.  We do this with a multiply.  If exp
+                * Denormalize the result.  We do this with a multiply. If expo
                 * is very large, it won't fit in a double, so we have to
                 * adjust the exponent first.  This is safe because we know



Home | Main Index | Thread Index | Old Index